@@ -149,7 +149,7 @@ class CommandProcessor:
     def list_commands(self):
         commands = list_commands(self.COMMAND_HOST)
         commands = dict(commands)
-        return sorted(set(commands.values()), key=lambda k: k.__repr__())
+        return sorted(set(commands.values()), key=repr)
 
 
 class Command:
