@@ -191,14 +191,11 @@ class StandardCommonChatCommands(CommandContainer):
     @command
     @doc(_("Clear the text window"))
     def clear(self):
-        self.conv_textview.clear()
+        self.conversation_view.clear()
 
     @command
     @doc(_("Send a ping to the contact"))
     def ping(self):
-        if self.account == app.ZEROCONF_ACC_NAME:
-            raise CommandError(
-                _('Command is not supported for zeroconf accounts'))
         app.connections[self.account].get_module('Ping').send_ping(self.contact)
 
     @command
@@ -272,7 +269,7 @@ class StandardGroupChatCommands(CommandContainer):
     @command
     @doc(_("Clear the text window"))
     def clear(self):
-        self.conv_textview.clear()
+        self.conversation_view.clear()
 
     @command(raw=True)
     @doc(_("Change your nickname in a group chat"))
@@ -289,7 +286,10 @@ class StandardGroupChatCommands(CommandContainer):
     @command('query', raw=True)
     @doc(_("Open a private chat window with a specified participant"))
     def chat(self, nick):
-        nicks = app.contacts.get_nick_list(self.account, self.room_jid)
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nicks = groupchat_contact.get_user_nicknames()
         if nick in nicks:
             self.send_pm(nick)
         else:
@@ -299,7 +299,10 @@ class StandardGroupChatCommands(CommandContainer):
     @doc(_("Open a private chat window with a specified participant and send "
            "him a message"))
     def message(self, nick, message):
-        nicks = app.contacts.get_nick_list(self.account, self.room_jid)
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nicks = groupchat_contact.get_user_nicknames()
         if nick in nicks:
             self.send_pm(nick, message)
         else:
@@ -316,8 +319,8 @@ class StandardGroupChatCommands(CommandContainer):
 
     @command(raw=True, empty=True)
     @doc(_("Invite a user to a group chat for a reason"))
-    def invite(self, jid, reason):
-        control = app.get_groupchat_control(self.account, self.room_jid)
+    def invite(self, jid, _reason):
+        control = app.window.get_control(self.account, self.room_jid)
         if control is not None:
             control.invite(jid)
 
@@ -331,11 +334,12 @@ class StandardGroupChatCommands(CommandContainer):
             'groupchat-join',
             GLib.Variant('as', [self.account, jid]))
 
-    @command('part', 'close', raw=True, empty=True)
-    @doc(_("Leave the group chat, optionally giving a reason, and close tab or "
-           "window"))
-    def leave(self, reason):
-        self.leave(reason=reason)
+    @command('part', 'close')
+    @doc(_("Leave the group chat"))
+    def leave(self):
+        # Use idle_add to let command system finish printing
+        variant = GLib.Variant('as', [self.account, str(self.room_jid)])
+        GLib.idle_add(app.window.activate_action, 'remove-chat', variant)
 
     @command(raw=True, empty=True)
     @doc(_("""
@@ -344,9 +348,12 @@ class StandardGroupChatCommands(CommandContainer):
     If given nickname is not found it will be treated as a JID.
     """))
     def ban(self, who, reason=''):
-        if who in app.contacts.get_nick_list(self.account, self.room_jid):
-            contact = app.contacts.get_gc_contact(
-                self.account, self.room_jid, who)
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nick_list = groupchat_contact.get_user_nicknames()
+        if who in nick_list:
+            contact = groupchat_contact.get_resource(who)
             who = contact.jid
         self.connection.get_module('MUC').set_affiliation(
             self.room_jid,
@@ -356,7 +363,11 @@ class StandardGroupChatCommands(CommandContainer):
     @command(raw=True, empty=True)
     @doc(_("Kick user from group chat by nickname"))
     def kick(self, who, reason):
-        if who not in app.contacts.get_nick_list(self.account, self.room_jid):
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nick_list = groupchat_contact.get_user_nicknames()
+        if who not in nick_list:
             raise CommandError(_("Nickname not found"))
         self.connection.get_module('MUC').set_role(
             self.room_jid, who, 'none', reason)
@@ -369,7 +380,11 @@ class StandardGroupChatCommands(CommandContainer):
     def role(self, who, role):
         if role not in ('moderator', 'participant', 'visitor', 'none'):
             raise CommandError(_("Invalid role given"))
-        if who not in app.contacts.get_nick_list(self.account, self.room_jid):
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nick_list = groupchat_contact.get_user_nicknames()
+        if who not in nick_list:
             raise CommandError(_("Nickname not found"))
         self.connection.get_module('MUC').set_role(self.room_jid, who, role)
 
@@ -381,9 +396,14 @@ class StandardGroupChatCommands(CommandContainer):
     def affiliate(self, who, affiliation):
         if affiliation not in ('owner', 'admin', 'member', 'outcast', 'none'):
             raise CommandError(_("Invalid affiliation given"))
-        if who not in app.contacts.get_nick_list(self.account, self.room_jid):
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nick_list = groupchat_contact.get_user_nicknames()
+        if who not in nick_list:
             raise CommandError(_("Nickname not found"))
-        contact = app.contacts.get_gc_contact(self.account, self.room_jid, who)
+
+        contact = groupchat_contact.get_resource(who)
 
         self.connection.get_module('MUC').set_affiliation(
             self.room_jid,
@@ -392,12 +412,17 @@ class StandardGroupChatCommands(CommandContainer):
     @command
     @doc(_("Display names of all group chat participants"))
     def names(self, verbose=False):
-        ggc = app.contacts.get_gc_contact
-        gnl = app.contacts.get_nick_list
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
 
-        get_contact = lambda nick: ggc(self.account, self.room_jid, nick)
-        get_role = lambda nick: get_contact(nick).role
-        nicks = gnl(self.account, self.room_jid)
+        def get_contact(nick):
+            return groupchat_contact.get_resource(nick)
+
+        def get_role(nick):
+            return get_contact(nick).role
+
+        nicks = groupchat_contact.get_user_nicknames()
 
         nicks = sorted(nicks)
         nicks = sorted(nicks, key=get_role)
@@ -424,10 +449,12 @@ class StandardGroupChatCommands(CommandContainer):
     @command
     @doc(_("Send a ping to the contact"))
     def ping(self, nick):
-        if self.account == app.ZEROCONF_ACC_NAME:
-            raise CommandError(
-                _('Command is not supported for zeroconf accounts'))
-        gc_c = app.contacts.get_gc_contact(self.account, self.room_jid, nick)
-        if gc_c is None:
+        client = app.get_client(self.account)
+        groupchat_contact = client.get_module('Contacts').get_contact(
+            self.room_jid, groupchat=True)
+        nick_list = groupchat_contact.get_user_nicknames()
+        if nick not in nick_list:
             raise CommandError(_("Unknown nickname"))
-        app.connections[self.account].get_module('Ping').send_ping(gc_c)
+
+        client.get_module('Ping').send_ping(
+            groupchat_contact.get_resource(nick))
