@@ -30,7 +30,7 @@ import gajim.gui
 from gajim.common import i18n
 
 
-_MIN_NBXMPP_VER = '3.0.0.dev3'
+_MIN_NBXMPP_VER = '3.0.0'
 _MIN_GTK_VER = '3.22.27'
 _MIN_CAIRO_VER = '1.16.0'
 _MIN_PYGOBJECT_VER = '3.32.0'
