@@ -16,10 +16,13 @@ import nbxmpp
 
 from gi.repository import Gdk
 from gi.repository import Gtk
+from gi.repository import GLib
 from gi.repository import GObject
 
+import cairo
+
 from gajim.common import app
-from gajim.common.helpers import launch_browser_mailer
+from gajim.common.helpers import open_uri
 from gajim.common.i18n import _
 from gajim.common.const import DEVS_CURRENT
 from gajim.common.const import DEVS_PAST
@@ -30,10 +33,10 @@ from gajim.common.const import THANKS
 class AboutDialog(Gtk.AboutDialog):
     def __init__(self):
         Gtk.AboutDialog.__init__(self)
-        self.set_transient_for(app.interface.roster.window)
+        self.set_transient_for(app.window)
         self.set_name('Gajim')
         self.set_version(app.version)
-        self.set_copyright('Copyright © 2003-2019 Gajim Team')
+        self.set_copyright('Copyright © 2003-2022 Gajim Team')
         self.set_license_type(Gtk.License.GPL_3_0_ONLY)
         self.set_website('https://gajim.org/')
 
@@ -42,13 +45,23 @@ class AboutDialog(Gtk.AboutDialog):
             Gtk.get_minor_version(),
             Gtk.get_micro_version())
         gobject_ver = '.'.join(map(str, GObject.pygobject_version))
+        glib_ver = '.'.join(map(str, [GLib.MAJOR_VERSION,
+                                      GLib.MINOR_VERSION,
+                                      GLib.MICRO_VERSION]))
+        cairo_ver = cairo.cairo_version_string()
+        python_cairo_ver = cairo.version
 
-        comments = []
-        comments.append(_('A GTK+ XMPP client'))
-        comments.append(_('GTK+ Version: %s' % gtk_ver))
+        comments: list[str] = []
+        comments.append(_('A fully-featured XMPP chat client'))
+        comments.append('')
+        comments.append(_('GTK Version: %s') % gtk_ver)
+        comments.append(_('GLib Version: %s') % glib_ver)
         comments.append(_('PyGObject Version: %s') % gobject_ver)
+        comments.append(_('Cairo Version: %s') % cairo_ver)
+        comments.append(_('python-cairo Version: %s') % python_cairo_ver)
         comments.append(_('python-nbxmpp Version: %s') % nbxmpp.__version__)
-        self.set_comments("\n".join(comments))
+
+        self.set_comments('\n'.join(comments))
 
         self.add_credit_section(_('Current Developers'), DEVS_CURRENT)
         self.add_credit_section(_('Past Developers'), DEVS_PAST)
@@ -63,29 +76,20 @@ class AboutDialog(Gtk.AboutDialog):
         self.set_translator_credits(_('translator-credits'))
         self.set_logo_icon_name('org.gajim.Gajim')
 
-        self.connect(
-            'response', lambda dialog, *args: Gtk.AboutDialog.do_close(dialog))
-
-        self.show()
         self.connect('activate-link', self._on_activate_link)
-        # See https://gitlab.gnome.org/GNOME/gtk/issues/1561
-        self._connect_link_handler(self)
+        self.connect('response', self._on_response)
+        self.show()
 
     @staticmethod
-    def _on_activate_link(_label, uri):
+    def _on_activate_link(_label: Gtk.Label, uri: str) -> int:
         # We have to use this, because the default GTK handler
         # is not cross-platform compatible
-        launch_browser_mailer(None, uri)
+        open_uri(uri)
         return Gdk.EVENT_STOP
 
-    def _connect_link_handler(self, parent):
-        def _find_child(parent_):
-            if not hasattr(parent_, 'get_children'):
-                return
-
-            for child in parent_.get_children():
-                if isinstance(child, Gtk.Label):
-                    if 'href' in child.get_label():
-                        child.connect('activate-link', self._on_activate_link)
-                _find_child(child)
-        _find_child(parent)
+    def _on_response(self,
+                     _dialog: Gtk.AboutDialog,
+                     response: Gtk.ResponseType
+                     ) -> None:
+        if response == Gtk.ResponseType.DELETE_EVENT:
+            self.destroy()
