@@ -125,7 +125,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             ('account-enabled', ged.GUI1, self._on_account_enabled),
             ('account-disabled', ged.GUI1, self._on_account_disabled),
             ('allow-gajim-update-check', ged.GUI1, self._on_allow_gajim_update),
-            ('gajim-update-available', ged.GUI1, self._on_gajim_update_available),
+            ('gajim-update-available', ged.GUI1,
+             self._on_gajim_update_available),
             ('roster-item-exchange', ged.GUI1, self._on_roster_item_exchange),
             ('plain-connection', ged.GUI1, self._on_plain_connection),
             ('password-required', ged.GUI1, self._on_password_required),
@@ -187,9 +188,9 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         window_width = app.settings.get('mainwin_width')
         window_height = app.settings.get('mainwin_height')
         resize_window(self, window_width, window_height)
+        restore_main_window_position()
 
         self.set_skip_taskbar_hint(not app.settings.get('show_in_taskbar'))
-
         self.show_all()
 
         show_main_window = app.settings.get('show_main_window_on_startup')
@@ -342,6 +343,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             'switch-tab-7',
             'switch-tab-8',
             'switch-tab-9',
+            'toggle-chat-list',
         ]
 
         disabled_for_emacs = (
@@ -362,31 +364,31 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                    action: Gio.SimpleAction,
                    _param: Optional[GLib.Variant]) -> Optional[int]:
 
-        control = self.get_active_control()
-        if control is None:
-            return None
-        log.info('Activate action: %s, active control: %s',
-                 action.get_name(), control.contact.jid)
-
         action_name = action.get_name()
+        log.info('Activate action: %s', action_name)
 
-        res = control.delegate_action(action_name)
-        if res != Gdk.EVENT_PROPAGATE:
-            return res
+        if action_name == 'escape' and self._chat_page.hide_search():
+            return None
 
-        if action_name == 'escape':
-            if self._chat_page.hide_search():
-                return None
+        control = self.get_active_control()
+        if control is not None:
 
-            if app.settings.get('escape_key_closes'):
+            res = control.delegate_action(action_name)
+            if res != Gdk.EVENT_PROPAGATE:
+                return res
+
+            if action_name == 'escape':
+                if app.settings.get('escape_key_closes'):
+                    self._chat_page.remove_chat(control.account,
+                                                control.contact.jid)
+                    return None
+
+            elif action_name == 'close-tab':
                 self._chat_page.remove_chat(control.account,
                                             control.contact.jid)
                 return None
 
-        elif action_name == 'close-tab':
-            self._chat_page.remove_chat(control.account, control.contact.jid)
-
-        elif action_name == 'switch-next-tab':
+        if action_name == 'switch-next-tab':
             self.select_next_chat(Direction.NEXT)
 
         elif action_name == 'switch-prev-tab':
@@ -402,6 +404,9 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             number = int(action_name[-1]) - 1
             self.select_chat_number(number)
 
+        elif action_name == 'toggle-chat-list':
+            self._chat_page.toggle_chat_list()
+
         return None
 
     def _on_window_motion_notify(self,
